==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/ts/Edit_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Préférences générales</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Préférences de dessin</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Restart required</source>
        <translation>Redémarrage nécessaire</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>S&apos;il vous plaît redémarrer QCAD
pour appliquer les modifications.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Point de référence</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Outils d&apos;édition</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Afficher les outils d&apos;édition</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Édition</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+85"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location line="-88"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Clear Search</source>
        <translation>Effacer la recherche</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Expand Tree</source>
        <translation>Développer la navigation</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Réduire la navigation</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Restaurer les valeurs par défaut</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/ts/Edit_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AbstractPreferences</name>
    <message>
        <location filename="../AbstractPreferences.js" line="+46"/>
        <source>Application Preferences</source>
        <translation>Préférences générales</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drawing Preferences</source>
        <translation>Préférences de dessin</translation>
    </message>
    <message>
        <location line="+300"/>
        <source>Apply preferences</source>
        <translation>Appliquer préférences</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Restart required</source>
        <translation>Redémarrage nécessaire</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please restart QCAD for
the preference changes to take effect.</source>
        <translation>S&apos;il vous plaît redémarrer QCAD
pour appliquer les modifications.</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Defaults for </source>
        <translation>Valeurs par défaut pour</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>These are default preferences for new drawings.</source>
        <translation>Ce sont préférences par défaut pour les nouveaux dessins.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Preferences of the current drawing can be changed under&lt;br/&gt;&lt;i&gt;Edit &amp;gt; Drawing Preferences&lt;/i&gt;.</source>
        <translation>Préférences du dessin courant peuvent être modifiés sous&lt;br/&gt;&lt;i&gt;Édition &amp;gt; Préférences de dessign&lt;/i&gt;.</translation>
    </message>
    <message>
        <source>You are changing default preferences for new drawings.</source>
        <translation type="vanished">Vous changez les préférences par défaut pour les nouveaux dessins.</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Changes will affect new drawings but NOT the current drawing.</source>
        <translation>Les changements auront une incidence sur les nouveaux dessins, mais pas le dessin en cours.</translation>
    </message>
</context>
<context>
    <name>ClipboardOperation</name>
    <message>
        <location filename="../ClipboardOperation.js" line="+52"/>
        <source>Reference point</source>
        <translation>Point de référence</translation>
    </message>
</context>
<context>
    <name>Edit</name>
    <message>
        <location filename="../Edit.js" line="+65"/>
        <source>Edit Tools</source>
        <translation>Outils d&apos;édition</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show edit tools</source>
        <translation>Afficher les outils d&apos;édition</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Edit</source>
        <translation>&amp;Édition</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../AbstractPreferences.ui" line="+14"/>
        <location line="+71"/>
        <location line="+21"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location line="-74"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Clear Search</source>
        <translation type="vanished">Effacer la recherche</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Expand Tree</source>
        <translation>Développer la navigation</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Collapse Tree</source>
        <translation>Réduire la navigation</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Restore to Default Values</source>
        <translation>Restaurer les valeurs par défaut</translation>
    </message>
</context>
</TS>
